svn commit: r221957 - head/sys/dev/mk48txx

Marius Strobl marius at FreeBSD.org
Sun May 15 13:17:08 UTC 2011


Author: marius
Date: Sun May 15 13:17:08 2011
New Revision: 221957
URL: http://svn.freebsd.org/changeset/base/221957

Log:
  Add support for MK48T37.

Modified:
  head/sys/dev/mk48txx/mk48txx.c
  head/sys/dev/mk48txx/mk48txxreg.h

Modified: head/sys/dev/mk48txx/mk48txx.c
==============================================================================
--- head/sys/dev/mk48txx/mk48txxreg.h	Sun May 15 13:07:34 2011	(r221956)
+++ head/sys/dev/mk48txx/mk48txxreg.h	Sun May 15 13:17:08 2011	(r221957)
@@ -152,5 +152,8 @@
 #define	MK48T18_CLKSZ		8192
 #define	MK48T18_CLKOFF		0x1ff0
 
+#define	MK48T37_CLKSZ		32768
+#define	MK48T37_CLKOFF		0x1ff0
+
 #define	MK48T59_CLKSZ		8192
 #define	MK48T59_CLKOFF		0x1ff0


More information about the svn-src-all mailing list
--- head/sys/dev/mk48txx/mk48txx.c	Sun May 15 13:07:34 2011	(r221956)
+++ head/sys/dev/mk48txx/mk48txx.c	Sun May 15 13:17:08 2011	(r221957)
@@ -33,7 +33,8 @@
 __FBSDID("$FreeBSD$");
 
 /*
  * Mostek MK48T02, MK48T08, MK48T18, MK48T59 time-of-day chip subroutines
  */
 
 #include <sys/param.h>
@@ -67,6 +68,7 @@ static const struct {
 	{ "mk48t02", MK48T02_CLKSZ, MK48T02_CLKOFF, 0 },
 	{ "mk48t08", MK48T08_CLKSZ, MK48T08_CLKOFF, 0 },
 	{ "mk48t18", MK48T18_CLKSZ, MK48T18_CLKOFF, 0 },
+	{ "mk48t37", MK48T37_CLKSZ, MK48T37_CLKOFF, MK48TXX_EXT_REGISTERS },
 	{ "mk48t59", MK48T59_CLKSZ, MK48T59_CLKOFF, MK48TXX_EXT_REGISTERS },
 };
 
@@ -33,7 +33,8 @@
 
 /*
- * Mostek MK48T02, MK48T08, MK48T18, MK48T59 time-of-day chip subroutines
+ * Mostek MK48T02, MK48T08, MK48T18, MK48T37 and MK48T59 time-of-day chip
+ * subroutines
  */
 

Modified: head/sys/dev/mk48txx/mk48txxreg.h
==============================================================================